/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2014 Red Hat, Inc., and individual contributors
 * as indicated by the @author tags.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.jdeparser;

import static org.jboss.jdeparser.Tokens.$KW;

import java.io.IOException;

/**
 * @author <a href="mailto:david.lloyd@redhat.com">David M. Lloyd</a>
 */
class ElseJBlock extends BasicJBlock {

    ElseJBlock(final ImplJIf _if) {
        this(_if, Braces.IF_MULTILINE);
    }

    ElseJBlock(final ImplJIf _if, final Braces braces) {
        super(_if.getParent(), braces);
    }

    void write(final SourceFileWriter writer, final FormatPreferences.Space beforeBrace, final Braces braces) throws IOException {
        writer.write(FormatPreferences.Space.BEFORE_KEYWORD_ELSE);
        writer.write($KW.ELSE);
        super.write(writer, beforeBrace, braces);
    }
}
